@@ -299,6 +299,9 @@ pub trait VsMgmt {
     /// Check if a branch exists or not.
     fn branch_exists(&self, branch_name: BranchName) -> bool;
 
+    /// Check if a branch exists and has versions on it.
+    fn branch_has_versions(&self, branch_name: BranchName) -> bool;
+
     /// Remove a branch, remove all changes directly made by this branch.
     ///
     /// 'Write'-like operations on branches and versions are different from operations on data.
@@ -483,6 +486,11 @@ macro_rules! impl_vs_methods {
             self.inner.branch_exists(branch_name)
         }
 
+        /// Check if a branch exists and has versions on it.
+        fn branch_has_versions(&self, branch_name: BranchName) -> bool {
+            self.inner.branch_has_versions(branch_name)
+        }
+
         /// Remove a branch, remove all changes directly made by this branch.
         ///
         /// 'Write'-like operations on branches and versions are different from operations on data.
@@ -651,7 +659,12 @@ macro_rules! impl_vs_methods_nope {
 
         #[inline(always)]
         fn branch_exists(&self, _: BranchName) -> bool {
-            true
+            false
+        }
+
+        #[inline(always)]
+        fn branch_has_versions(&self, _: BranchName) -> bool {
+            false
         }
 
         #[inline(always)]
@@ -954,9 +967,17 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
     #[inline(always)]
     fn branch_exists(&self, branch_name: BranchName) -> bool {
         if let Some(i) = self.as_ref() {
-            alt!(!i.branch_exists(branch_name), return false);
+            return i.branch_exists(branch_name);
         }
-        true
+        false
+    }
+
+    #[inline(always)]
+    fn branch_has_versions(&self, branch_name: BranchName) -> bool {
+        if let Some(i) = self.as_ref() {
+            return i.branch_has_versions(branch_name);
+        }
+        false
     }
 
     #[inline(always)]
@@ -1169,10 +1190,22 @@ macro_rules! impl_for_collections {
 
         #[inline(always)]
         fn branch_exists(&self, branch_name: BranchName) -> bool {
+            let mut exists = false;
             for i in self.$values() {
+                exists = true;
                 alt!(!i.branch_exists(branch_name), return false);
             }
-            true
+            exists
+        }
+
+        #[inline(always)]
+        fn branch_has_versions(&self, branch_name: BranchName) -> bool {
+            let mut exists = false;
+            for i in self.$values() {
+                exists = true;
+                alt!(!i.branch_has_versions(branch_name), return false);
+            }
+            exists
         }
 
         #[inline(always)]
